@@ -1,9 +1,9 @@
-from typing import List, Optional
+from __future__ import annotations
 
-__version__ = "25.1.1"
+__version__ = "25.2"
 
 
-def main(args: Optional[List[str]] = None) -> int:
+def main(args: list[str] | None = None) -> int:
     """This is an internal API only meant for use by pip's own console scripts.
 
     For additional details, see https://github.com/pypa/pip/issues/7498.
